==> plxArtTooOld_1.0.1_01092017.zip: plxArtTooOld/config.php <==
<?php if(!defined('PLX_ROOT')) exit; ?>
<?php
/**
 * Plugin for Pluxml
 * @author	DPFPIC
 * Site : http://dpfpic.com
 * Licence GNU_GPL
 **/
 
# Control du token du formulaire
plxToken::validateFormToken($_POST);

$init = true;

if(!empty($_POST)) {

	$plxPlugin->setParam('refDate', $_POST['refDate'], 'string');
	$plxPlugin->setParam('miniDays', $_POST['miniDays'], 'numeric');
	$plxPlugin->setParam('excluCat', $_POST['excluCat'], 'string');
	$plxPlugin->setParam('backgrColor', $_POST['backgrColor'], 'string');
	$plxPlugin->setParam('textColor', $_POST['textColor'], 'string');
	$plxPlugin->setParam('borderColor', $_POST['borderColor'], 'string');	
	$plxPlugin->setParam('linkColor', $_POST['linkColor'], 'string');	
	$plxPlugin->setParam('warningMsg', $_POST['warningMsg'], 'cdata');

	$plxPlugin->saveParams();
	header('Location: parametres_plugin.php?p=plxArtTooOld');
	exit;

} else {

$refDate = $plxPlugin->getParam('refDate')=='' ? 'startdate' : $plxPlugin->getParam('refDate');
$miniDays = $plxPlugin->getParam('miniDays')=='' ? 90 : $plxPlugin->getParam('miniDays');
$excluCat = $plxPlugin->getParam('excluCat')=='' ? '' : $plxPlugin->getParam('excluCat');
$backgrColor = $plxPlugin->getParam('backgrColor')=='' ? '#fff6bf' : $plxPlugin->getParam('backgrColor');
$textColor = $plxPlugin->getParam('textColor')=='' ? '#444' : $plxPlugin->getParam('textColor');
$borderColor = $plxPlugin->getParam('borderColor')=='' ? '#ffd324' : $plxPlugin->getParam('borderColor');
$linkColor = $plxPlugin->getParam('linkColor')=='' ? '#817134' : $plxPlugin->getParam('linkColor');
$warningMsg = $plxPlugin->getParam('warningMsg')=='' ? $plxPlugin->getLang('L_ATO_CONTENT') : $plxPlugin->getParam('warningMsg');
}

echo "\n\t".'<link rel="stylesheet" href="'.PLX_PLUGINS.'plxArtTooOld/css/plxArtTooOld.css" type="text/css" media="screen" />'."\n";	
echo "\t".'<style type="text/css">'."\n";
echo "\t".'.ikaz {'."\n";
echo "\t".'max-width: 800px;'."\n";
echo "\t".'color: #'.$textColor.';'."\n";
echo "\t".'background: #'.$backgrColor.' url('.PLX_PLUGINS.'plxArtTooOld/img/ikaz.png) 2.2em center no-repeat;'."\n";
echo "\t".'border-color: #'.$borderColor.';'."\n";
echo "\t".'}'."\n";	
echo "\t".'.ikaz a {'."\n";
echo "\t".'color: #'.$linkColor."\n";
echo "\t".'}'."\n";
echo "\t".'</style>'."\n";


?>
<?php if ($plxAdmin->aConf['version'] < '5.4') { ?>
<h2><?php echo $plxPlugin->getInfo('title') ?></h2>
<?php } ?>
<link rel="stylesheet" href="<?php echo PLX_PLUGINS; ?>plxArtTooOld/css/config.css" type="text/css" media="screen" />
<script type="text/javascript" src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/js/config.js"></script>
<div>
	<span class="tab_0 tab" id="tab_01" onclick="javascript:change_tab('01');"><?php $plxPlugin->lang('L_ATO_TAB01') ?></span>
	<span class="tab_0 tab" id="tab_02" onclick="javascript:change_tab('02');"><?php $plxPlugin->lang('L_ATO_TAB02') ?></span>
</div>
<div class="content_tab" id="content_tab_01">
<form class="inline-form" id="form_plxArtTooOld" action="parametres_plugin.php?p=plxArtTooOld" method="post">

	<fieldset>
		<div class="grid">
			<div class="col sml-12">
			<label for="id_refDate"><?php echo $plxPlugin->lang('L_ATO_REFDATE') ?>&nbsp;:</label>
			<?php plxUtils::printSelect('refDate',array('startdate'=>$plxPlugin->getLang('L_ATO_STARTDATE'),'updatedate'=>$plxPlugin->getLang('L_ATO_UPDATEDATE')),$refDate); ?>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">	
				<label for="id_miniDays"><?php $plxPlugin->lang('L_ATO_MINIDAYS') ?>&nbsp;:</label>
				<?php plxUtils::printInput('miniDays',$miniDays,'text','4-4') ?>
				<a class="hint"><span><?php $plxPlugin->lang('L_ATO_HELP_MINIDAYS') ?></span></a>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">
			<label for="id_excluCat"><?php $plxPlugin->lang('L_ATO_EXCLUCAT') ?>&nbsp;:</label>
			<?php plxUtils::printInput('excluCat',$excluCat,'text','64-120') ?>
			<a class="hint"><span><?php $plxPlugin->lang('L_ATO_HELP_EXCLUCAT') ?></span></a>
			</div>
		</div>		
		<div class="grid">
			<div class="col sml-12">
			<label for="id_backgrColor"><?php $plxPlugin->lang('L_ATO_BACKGRCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('backgrColor',$backgrColor,'text','6-6',false,'color') ?>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">
			<label for="id_textColor"><?php $plxPlugin->lang('L_ATO_TEXTCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('textColor',$textColor,'text','6-6',false,'color') ?>
			</div>
		</div>
		<div class="grid">
			<div class="col sml-12">
			<label for="id_borderColor"><?php $plxPlugin->lang('L_ATO_BORDERCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('borderColor',$borderColor,'text','6-6',false,'color') ?>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">
			<label for="id_linkColor"><?php $plxPlugin->lang('L_ATO_LINKCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('linkColor',$linkColor,'text','6-6',false,'color') ?>
			</div>
		</div>		
		<div class="grid">
			<div class="col sml-12">
			<label for="id_warningMsg"><?php echo $plxPlugin->lang('L_ATO_WARNINGMSG') ?>&nbsp;:</label>
			<?php plxUtils::printArea('warningMsg',plxUtils::strCheck($warningMsg),35,8,false,'full-width'); ?>
			<span><strong><?php $plxPlugin->lang('L_ATO_HELP_WARNINGMSG') ?></strong></span>
			</div>
		</div>		
		<div class="grid">
			<div class="col sml-12">
			<label for="id_prewiew"><?php echo $plxPlugin->lang('L_ATO_PREVIEW') ?>&nbsp;:</label>
			<div class="ikaz">
			<a href="#" class="kapat">
			<img src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/img/cross_grey_small.png" title="Close this notification" alt="close"></a>
			<?php echo $warningMsg; ?>
			</div>
			</div>
		</div>			
		</div>			
		<p class="in-action-bar">
			<?php echo plxToken::getTokenPostMethod() ?>
			<input type="submit" name="submit" value="<?php $plxPlugin->lang('L_ATO_SAVE') ?>" />
		</p>
	</fieldset>
</form>
<div class="content_tab" id="content_tab_02">
	<div id="update">
		<?php $infoPlugin = $plxPlugin->arttooold->UpdatePlugin('plxArtTooOld'); ?>
		<p><?php $plxPlugin->lang('L_VP_ACTUAL_VERSION'); ?>&nbsp;:&nbsp;<?php echo $infoPlugin['actualversion'].' ('.$infoPlugin['actualdate'].')'; ?></p>	
		<?php if ($infoPlugin['status'] == 0) { ?>
			<p class="center"><span class="color"><?php $plxPlugin->lang('L_VP_ERROR'); ?></span></p>
			<p><a href="http://dpfpic.com" target="blank" title=""><img src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/img/vers/up_warning.gif" alt=""></a></p>
		<?php } elseif ($infoPlugin['status'] == 1) { ?>
			<p><?php $plxPlugin->lang('L_VP_LAST_VERSION'); ?>&nbsp;<?php echo $infoPlugin['newplugin']; ?>.</p>
			<p><img src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/img/vers/up_ok.gif" alt=""></p>
		<?php } elseif ($infoPlugin['status'] == 2) { ?>
			<p><?php $plxPlugin->lang('L_VP_NEW_VERSION'); ?><p>
			<p><span class="color"><?php echo $infoPlugin['newplugin']; ?>&nbsp;(<?php echo $infoPlugin['newversion']; ?>&nbsp;-&nbsp;<?php echo $infoPlugin['newdate']; ?>)</span></p>
			<p><?php $plxPlugin->lang('L_VP_NEW2_VERSION'); ?>.</p>
			<p><a href="<?php echo $infoPlugin['newurl']; ?>" target="blank" title=""><img src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/img/vers/up_download.gif" alt=""></a></p>
		<?php } elseif ($infoPlugin['status'] == 3) {?>
		    <p class="center"><span class="color"><?php $plxPlugin->lang('L_VP_DESACTIVED'); ?></span></p>
			<p><a href="http://dpfpic.com" target="blank" title=""><img src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/img/vers/up_warning.gif" alt=""></a></p>
		<?php } ?>	
	</div>
</div>	
<script type="text/javascript">
var anc_tab = '01';
change_tab(anc_tab);
</script>

==> plxArtTooOld.1.0.3.zip: plxArtTooOld/config.php <==
<?php if(!defined('PLX_ROOT')) exit; ?>
<?php
/**
 * Plugin for Pluxml
 * @author	DPFPIC
 * Site : http://monblog.dpfpic.com/
 * Licence GNU_GPL
 **/
 
# Control du token du formulaire
plxToken::validateFormToken($_POST);

$init = true;

if(!empty($_POST)) {

	$plxPlugin->setParam('refDate', $_POST['refDate'], 'string');
	$plxPlugin->setParam('miniDays', $_POST['miniDays'], 'numeric');
	$plxPlugin->setParam('excluCat', $_POST['excluCat'], 'string');
	$plxPlugin->setParam('backgrColor', $_POST['backgrColor'], 'string');
	$plxPlugin->setParam('textColor', $_POST['textColor'], 'string');
	$plxPlugin->setParam('borderColor', $_POST['borderColor'], 'string');	
	$plxPlugin->setParam('linkColor', $_POST['linkColor'], 'string');	
	$plxPlugin->setParam('warningMsg', $_POST['warningMsg'], 'cdata');

	$plxPlugin->saveParams();
	header('Location: parametres_plugin.php?p=plxArtTooOld');
	exit;

} else {

$refDate = $plxPlugin->getParam('refDate')=='' ? 'startdate' : $plxPlugin->getParam('refDate');
$miniDays = $plxPlugin->getParam('miniDays')=='' ? 90 : $plxPlugin->getParam('miniDays');
$excluCat = $plxPlugin->getParam('excluCat')=='' ? '' : $plxPlugin->getParam('excluCat');
$backgrColor = $plxPlugin->getParam('backgrColor')=='' ? '#fff6bf' : $plxPlugin->getParam('backgrColor');
$textColor = $plxPlugin->getParam('textColor')=='' ? '#444' : $plxPlugin->getParam('textColor');
$borderColor = $plxPlugin->getParam('borderColor')=='' ? '#ffd324' : $plxPlugin->getParam('borderColor');
$linkColor = $plxPlugin->getParam('linkColor')=='' ? '#817134' : $plxPlugin->getParam('linkColor');
$warningMsg = $plxPlugin->getParam('warningMsg')=='' ? $plxPlugin->getLang('L_ATO_CONTENT') : $plxPlugin->getParam('warningMsg');
}

echo "\n\t".'<link rel="stylesheet" href="'.PLX_PLUGINS.'plxArtTooOld/css/plxArtTooOld.css" type="text/css" media="screen" />'."\n";	
echo "\t".'<style type="text/css">'."\n";
echo "\t".'.ikaz {'."\n";
echo "\t".'max-width: 800px;'."\n";
echo "\t".'color: #'.$textColor.';'."\n";
echo "\t".'background: #'.$backgrColor.' url('.PLX_PLUGINS.'plxArtTooOld/img/ikaz.png) 2.2em center no-repeat;'."\n";
echo "\t".'border-color: #'.$borderColor.';'."\n";
echo "\t".'}'."\n";	
echo "\t".'.ikaz a {'."\n";
echo "\t".'color: #'.$linkColor."\n";
echo "\t".'}'."\n";
echo "\t".'</style>'."\n";


?>
<?php if ($plxAdmin->aConf['version'] < '5.4') { ?>
<h2><?php echo $plxPlugin->getInfo('title') ?></h2>
<?php } ?>
<link rel="stylesheet" href="<?php echo PLX_PLUGINS; ?>plxArtTooOld/css/config.css" type="text/css" media="screen" />
<script type="text/javascript" src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/js/config.js"></script>
<div>
	<span class="tab_0 tab" id="tab_01" onclick="javascript:change_tab('01');"><?php $plxPlugin->lang('L_ATO_TAB01') ?></span>
</div>
<div class="content_tab" id="content_tab_01">
<form class="inline-form" id="form_plxArtTooOld" action="parametres_plugin.php?p=plxArtTooOld" method="post">

	<fieldset>
		<div class="grid">
			<div class="col sml-12">
			<label for="id_refDate"><?php echo $plxPlugin->lang('L_ATO_REFDATE') ?>&nbsp;:</label>
			<?php plxUtils::printSelect('refDate',array('startdate'=>$plxPlugin->getLang('L_ATO_STARTDATE'),'updatedate'=>$plxPlugin->getLang('L_ATO_UPDATEDATE')),$refDate); ?>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">	
				<label for="id_miniDays"><?php $plxPlugin->lang('L_ATO_MINIDAYS') ?>&nbsp;:</label>
				<?php plxUtils::printInput('miniDays',$miniDays,'text','4-4') ?>
				<a class="hint"><span><?php $plxPlugin->lang('L_ATO_HELP_MINIDAYS') ?></span></a>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">
			<label for="id_excluCat"><?php $plxPlugin->lang('L_ATO_EXCLUCAT') ?>&nbsp;:</label>
			<?php plxUtils::printInput('excluCat',$excluCat,'text','64-120') ?>
			<a class="hint"><span><?php $plxPlugin->lang('L_ATO_HELP_EXCLUCAT') ?></span></a>
			</div>
		</div>		
		<div class="grid">
			<div class="col sml-12">
			<label for="id_backgrColor"><?php $plxPlugin->lang('L_ATO_BACKGRCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('backgrColor',$backgrColor,'text','6-6',false,'color') ?>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">
			<label for="id_textColor"><?php $plxPlugin->lang('L_ATO_TEXTCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('textColor',$textColor,'text','6-6',false,'color') ?>
			</div>
		</div>
		<div class="grid">
			<div class="col sml-12">
			<label for="id_borderColor"><?php $plxPlugin->lang('L_ATO_BORDERCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('borderColor',$borderColor,'text','6-6',false,'color') ?>
			</div>
		</div>	
		<div class="grid">
			<div class="col sml-12">
			<label for="id_linkColor"><?php $plxPlugin->lang('L_ATO_LINKCOLOR') ?>&nbsp;:</label>
			<?php plxUtils::printInput('linkColor',$linkColor,'text','6-6',false,'color') ?>
			</div>
		</div>		
		<div class="grid">
			<div class="col sml-12">
			<label for="id_warningMsg"><?php echo $plxPlugin->lang('L_ATO_WARNINGMSG') ?>&nbsp;:</label>
			<?php plxUtils::printArea('warningMsg',plxUtils::strCheck($warningMsg),35,8,false,'full-width'); ?>
			<span><strong><?php $plxPlugin->lang('L_ATO_HELP_WARNINGMSG') ?></strong></span>
			</div>
		</div>		
		<div class="grid">
			<div class="col sml-12">
			<label for="id_prewiew"><?php echo $plxPlugin->lang('L_ATO_PREVIEW') ?>&nbsp;:</label>
			<div class="ikaz">
			<a href="#" class="kapat">
			<img src="<?php echo PLX_PLUGINS; ?>plxArtTooOld/img/cross_grey_small.png" title="Close this notification" alt="close"></a>
			<?php echo $warningMsg; ?>
			</div>
			</div>
		</div>			
		</div>			
		<p class="in-action-bar">
			<?php echo plxToken::getTokenPostMethod() ?>
			<input type="submit" name="submit" value="<?php $plxPlugin->lang('L_ATO_SAVE') ?>" />
		</p>
	</fieldset>
</form>
<script type="text/javascript">
var anc_tab = '01';
change_tab(anc_tab);
</script>
